==> redwood-layout-compose-jvm-0.2.0-sources.jar: commonMain/app/cash/redwood/layout/compose/Row.kt <==
package app.cash.redwood.layout.compose

import androidx.compose.runtime.Composable
import app.cash.redwood.LayoutModifier
import app.cash.redwood.RedwoodCodegenApi
import app.cash.redwood.compose.RedwoodComposeNode
import app.cash.redwood.layout.api.Constraint
import app.cash.redwood.layout.api.CrossAxisAlignment
import app.cash.redwood.layout.api.MainAxisAlignment
import app.cash.redwood.layout.api.Overflow
import app.cash.redwood.layout.api.Padding
import app.cash.redwood.layout.widget.RedwoodLayoutWidgetFactoryProvider
import app.cash.redwood.layout.widget.Row
import kotlin.OptIn
import kotlin.Unit

@Composable
@OptIn(RedwoodCodegenApi::class)
public fun Row(
  width: Constraint = Constraint.Wrap,
  height: Constraint = Constraint.Wrap,
  padding: Padding = Padding.Zero,
  overflow: Overflow = Overflow.Clip,
  horizontalAlignment: MainAxisAlignment = MainAxisAlignment.Start,
  verticalAlignment: CrossAxisAlignment = CrossAxisAlignment.Start,
  layoutModifier: LayoutModifier = LayoutModifier,
  children: @Composable RowScope.() -> Unit,
): Unit {
  RedwoodComposeNode<RedwoodLayoutWidgetFactoryProvider<*>, Row<*>>(
      factory = { it.RedwoodLayout.Row() },
      update = {
        set(layoutModifier) { layoutModifiers = it }
        set(width, Row<*>::width)
        set(height, Row<*>::height)
        set(padding, Row<*>::padding)
        set(overflow, Row<*>::overflow)
        set(horizontalAlignment, Row<*>::horizontalAlignment)
        set(verticalAlignment, Row<*>::verticalAlignment)
      },
      content = {
        into(Row<*>::children) {
          RowScopeImpl.children()
        }
      },
      )
}

==> redwood-layout-compose-jvm-0.7.0-sources.jar: commonMain/app/cash/redwood/layout/compose/Row.kt <==
package app.cash.redwood.layout.compose

import androidx.compose.runtime.Composable
import app.cash.redwood.Modifier
import app.cash.redwood.RedwoodCodegenApi
import app.cash.redwood.compose.RedwoodComposeNode
import app.cash.redwood.compose.WidgetNode
import app.cash.redwood.layout.api.Constraint
import app.cash.redwood.layout.api.CrossAxisAlignment
import app.cash.redwood.layout.api.MainAxisAlignment
import app.cash.redwood.layout.api.Overflow
import app.cash.redwood.layout.widget.RedwoodLayoutWidgetFactoryProvider
import app.cash.redwood.layout.widget.Row
import app.cash.redwood.ui.Margin
import kotlin.OptIn
import kotlin.Unit

@Composable
@OptIn(RedwoodCodegenApi::class)
public fun Row(
  width: Constraint = Constraint.Wrap,
  height: Constraint = Constraint.Wrap,
  margin: Margin = Margin.Zero,
  overflow: Overflow = Overflow.Clip,
  horizontalAlignment: MainAxisAlignment = MainAxisAlignment.Start,
  verticalAlignment: CrossAxisAlignment = CrossAxisAlignment.Start,
  modifier: Modifier = Modifier,
  children: @Composable RowScope.() -> Unit,
) {
  RedwoodComposeNode<RedwoodLayoutWidgetFactoryProvider<*>, Row<*>>(
      factory = { it.RedwoodLayout.Row() },
      update = {
        set(modifier, WidgetNode.SetModifiers)
        set(width) { recordChanged(); widget.width(it) }
        set(height) { recordChanged(); widget.height(it) }
        set(margin) { recordChanged(); widget.margin(it) }
        set(overflow) { recordChanged(); widget.overflow(it) }
        set(horizontalAlignment) { recordChanged(); widget.horizontalAlignment(it) }
        set(verticalAlignment) { recordChanged(); widget.verticalAlignment(it) }
      },
      content = {
        into(Row<*>::children) {
          RowScopeImpl.children()
        }
      },
      )
}
